@@ -4,12 +4,12 @@ predict.grain <- function(object, response, predictors=setdiff(names(newdata), r
 
   if (!inherits(object, "compgrain"))
     object <- compile(object, propagate=TRUE)
-  
+
   type <- match.arg(type, c("class","distribution"))
   nstate <- nodeStates(object,response)
   if (missing(predictors))
     predictors  <- setdiff(names(newdata),response)
-  
+
   p.evec <- rep(NA, nrow(newdata))
   ans <- lapply(nstate, function(a)
                 {
@@ -22,7 +22,7 @@ predict.grain <- function(object, response, predictors=setdiff(names(newdata), r
     case      <- newdata[i,predictors, drop=FALSE]
     ##     no <<- names(case)
     ##     st <<- case
-    
+
     objecttmp1    <- setFinding(object, nodes=names(case), states=case)
     p.e       <- pFinding(objecttmp1)
     if (p.e < .Machine$double.xmin){
@@ -30,15 +30,14 @@ predict.grain <- function(object, response, predictors=setdiff(names(newdata), r
                   i, .Machine$double.xmin))
       return(NULL)
     }
-    
+
     p.evec[i] <- p.e
     for (j in 1:length(response)){
-      ##pj   <- nodeMarginal(objecttmp1, response[j])[[1]]$values
-      pj   <- nodeMarginal(objecttmp1, response[j])[[1]] ## BRIS
+      pj   <- .nodeMarginal(objecttmp1, response[j])[[1]] ## BRIS
       #print(pj)
       ans[[j]][i,] <- pj
     }
-  } 
+  }
 
   #print(ans)
   if (type=="class"){
@@ -48,11 +47,11 @@ predict.grain <- function(object, response, predictors=setdiff(names(newdata), r
       #print(a)
       mlc <- apply(a,1,which.max)
       #print(mlc)
-      
+
       ans[[i]] <- ns[[i]][mlc]
     }
   }
-  
+
   value <- list(pred=ans, pFinding=p.evec)
   return(value)
 }
